/// <reference types="node" />
import type { JWT as JoseJWT, JWE } from "jose";
import { decode, encode } from ".";
export interface DefaultJWT extends Record<string, unknown> {
    name?: string | null;
    email?: string | null;
    picture?: string | null;
    sub?: string;
}
/**
 * Returned by the `jwt` callback and `getToken`, when using JWT sessions
 *
 * [`jwt` callback](https://next-auth.js.org/configuration/callbacks#jwt-callback) | [`getToken`](https://next-auth.js.org/tutorials/securing-pages-and-api-routes#using-gettoken)
 */
export interface JWT extends Record<string, unknown>, DefaultJWT {
}
export interface JWTEncodeParams {
    token?: JWT;
    maxAge?: number;
    secret: string | Buffer;
    signingKey?: string;
    signingOptions?: JoseJWT.SignOptions;
    encryptionKey?: string;
    encryptionOptions?: object;
    encryption?: boolean;
}
export interface JWTDecodeParams {
    token?: string;
    maxAge?: number;
    secret: string | Buffer;
    signingKey?: string;
    verificationKey?: string;
    verificationOptions?: JoseJWT.VerifyOptions<false>;
    encryptionKey?: string;
    decryptionKey?: string;
    decryptionOptions?: JWE.DecryptOptions<false>;
    encryption?: boolean;
}
export interface JWTOptions {
    secret: string;
    maxAge: number;
    encryption?: boolean;
    signingKey?: string;
    encryptionKey?: string;
    encode: typeof encode;
    decode: typeof decode;
    verificationOptions?: JoseJWT.VerifyOptions<false>;
}
