"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var jwt = _interopRequireWildcard(require("../jwt"));

var _parseUrl = _interopRequireDefault(require("../lib/parse-url"));

var _logger = _interopRequireWildcard(require("../lib/logger"));

var cookie = _interopRequireWildcard(require("./lib/cookie"));

var _defaultCallbacks = require("./lib/default-callbacks");

var _providers = _interopRequireDefault(require("./lib/providers"));

var routes = _interopRequireWildcard(require("./routes"));

var _pages = _interopRequireDefault(require("./pages"));

var _callbackUrlHandler = _interopRequireDefault(require("./lib/callback-url-handler"));

var _extendRes = _interopRequireDefault(require("./lib/extend-res"));

var _csrfTokenHandler = _interopRequireDefault(require("./lib/csrf-token-handler"));

var _errors = require("./errors");

var _utils = _interopRequireDefault(require("./lib/utils"));

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

if (!process.env.NEXTAUTH_URL) {
  _logger.default.warn("NEXTAUTH_URL");
}

async function NextAuthHandler(req, res, userOptions) {
  var _process$env$NEXTAUTH, _userOptions$useSecur, _userOptions$events, _process$env$NEXTAUTH2;

  if (userOptions.logger) {
    (0, _logger.setLogger)(userOptions.logger);
  }

  if (userOptions.debug) {
    ;
    process.env._NEXTAUTH_DEBUG = true;
  }

  (0, _extendRes.default)(req, res);

  if (!req.query.nextauth) {
    const message = "Cannot find [...nextauth].js in pages/api/auth. Make sure the filename is written correctly.";

    _logger.default.error("MISSING_NEXTAUTH_API_ROUTE_ERROR", new Error(message));

    return res.status(500).end(`Error: ${message}`);
  }

  const {
    nextauth,
    action = nextauth[0],
    providerId = nextauth[1],
    error = nextauth[1]
  } = req.query;
  delete req.query.nextauth;
  const {
    basePath,
    baseUrl
  } = (0, _parseUrl.default)((_process$env$NEXTAUTH = process.env.NEXTAUTH_URL) !== null && _process$env$NEXTAUTH !== void 0 ? _process$env$NEXTAUTH : process.env.VERCEL_URL);
  const cookies = { ...cookie.defaultCookies((_userOptions$useSecur = userOptions.useSecureCookies) !== null && _userOptions$useSecur !== void 0 ? _userOptions$useSecur : baseUrl.startsWith("https://")),
    ...userOptions.cookies
  };
  const secret = (0, _utils.default)({
    userOptions,
    basePath,
    baseUrl
  });
  const {
    providers,
    provider
  } = (0, _providers.default)({
    providers: userOptions.providers,
    base: `${baseUrl}${basePath}`,
    providerId: providerId
  });
  const maxAge = 30 * 24 * 60 * 60;
  const options = {
    debug: false,
    pages: {},
    theme: {
      colorScheme: "auto",
      logo: "",
      brandColor: ""
    },
    ...userOptions,
    baseUrl,
    basePath,
    action: action,
    provider,
    cookies,
    secret,
    providers,
    session: {
      jwt: !userOptions.adapter,
      maxAge,
      updateAge: 24 * 60 * 60,
      ...userOptions.session
    },
    jwt: {
      secret,
      maxAge,
      encode: jwt.encode,
      decode: jwt.decode,
      ...userOptions.jwt
    },
    events: (0, _errors.eventsErrorHandler)((_userOptions$events = userOptions.events) !== null && _userOptions$events !== void 0 ? _userOptions$events : {}, _logger.default),
    adapter: (0, _errors.adapterErrorHandler)(userOptions.adapter, _logger.default),
    callbacks: { ..._defaultCallbacks.defaultCallbacks,
      ...userOptions.callbacks
    },
    logger: _logger.default,
    callbackUrl: (_process$env$NEXTAUTH2 = process.env.NEXTAUTH_URL) !== null && _process$env$NEXTAUTH2 !== void 0 ? _process$env$NEXTAUTH2 : "http://localhost:3000"
  };
  req.options = options;
  (0, _csrfTokenHandler.default)(req, res);
  await (0, _callbackUrlHandler.default)(req, res);
  const render = (0, _pages.default)(req, res);
  const {
    pages
  } = req.options;

  if (req.method === "GET") {
    switch (action) {
      case "providers":
        return routes.providers(req, res);

      case "session":
        return await routes.session(req, res);

      case "csrf":
        return res.json({
          csrfToken: req.options.csrfToken
        });

      case "signin":
        if (pages.signIn) {
          let signinUrl = `${pages.signIn}${pages.signIn.includes("?") ? "&" : "?"}callbackUrl=${req.options.callbackUrl}`;

          if (error) {
            signinUrl = `${signinUrl}&error=${error}`;
          }

          return res.redirect(signinUrl);
        }

        return render.signin();

      case "signout":
        if (pages.signOut) return res.redirect(pages.signOut);
        return render.signout();

      case "callback":
        if (provider) {
          return await routes.callback(req, res);
        }

        break;

      case "verify-request":
        if (pages.verifyRequest) {
          return res.redirect(pages.verifyRequest);
        }

        return render.verifyRequest();

      case "error":
        if (pages.error) {
          return res.redirect(`${pages.error}${pages.error.includes("?") ? "&" : "?"}error=${error}`);
        }

        if (["Signin", "OAuthSignin", "OAuthCallback", "OAuthCreateAccount", "EmailCreateAccount", "Callback", "OAuthAccountNotLinked", "EmailSignin", "CredentialsSignin", "SessionRequired"].includes(error)) {
          return res.redirect(`${baseUrl}${basePath}/signin?error=${error}`);
        }

        return render.error({
          error
        });

      default:
    }
  } else if (req.method === "POST") {
    switch (action) {
      case "signin":
        if (req.options.csrfTokenVerified && provider) {
          return await routes.signin(req, res);
        }

        return res.redirect(`${baseUrl}${basePath}/signin?csrf=true`);

      case "signout":
        if (req.options.csrfTokenVerified) {
          return await routes.signout(req, res);
        }

        return res.redirect(`${baseUrl}${basePath}/signout?csrf=true`);

      case "callback":
        if (provider) {
          if (provider.type === "credentials" && !req.options.csrfTokenVerified) {
            return res.redirect(`${baseUrl}${basePath}/signin?csrf=true`);
          }

          return await routes.callback(req, res);
        }

        break;

      case "_log":
        if (userOptions.logger) {
          try {
            const {
              code,
              level,
              ...metadata
            } = req.body;

            _logger.default[level](code, metadata);
          } catch (error) {
            _logger.default.error("LOGGER_ERROR", error);
          }
        }

        return res.end();

      default:
    }
  }

  return res.status(400).end(`Error: HTTP ${req.method} is not supported for ${req.url}`);
}

function NextAuth(...args) {
  if (args.length === 1) {
    return async (req, res) => await NextAuthHandler(req, res, args[0]);
  }

  return NextAuthHandler(args[0], args[1], args[2]);
}

var _default = NextAuth;
exports.default = _default;